@@ -817,6 +817,9 @@ aft_dmachain_enable_tdmv_and_mtu_size(u32 *reg, int size)
 #define AFT_SERIAL_LCFG_DTR_BIT  	1
 #define AFT_SERIAL_LCFG_CTS_BIT  	2
 #define AFT_SERIAL_LCFG_DCD_BIT  	3
+
+#define AFT_SERIAL_LCFG_CTRL_BIT_MASK 0x0F
+
 #define AFT_SERIAL_LCFG_POLARITY_BIT 	4
 #define AFT_SERIAL_LCFG_SWMODE_BIT	5
 
@@ -1286,6 +1289,10 @@ enum {
 	
 #define UDPMGMT_SIGNATURE		"AFTPIPEA"
 
+#define AFT_SERIAL_MODEM_RTS  	1
+#define AFT_SERIAL_MODEM_DTR  	2
+#define AFT_SERIAL_MODEM_CTS  	4
+#define AFT_SERIAL_MODEM_DCD  	8
 
 /* the line trace status element presented by the frame relay code */
 typedef struct {
@@ -1397,6 +1404,10 @@ typedef struct {
 
 } aft_comm_err_stats_t;
 
+typedef struct {
+	unsigned int status;
+} api_serial_hdr_t;
+
 enum wanpipe_aft_api_events {
 	WP_API_EVENT_NONE,
 	WP_API_EVENT_DTMF,
@@ -1413,6 +1424,7 @@ enum wanpipe_aft_api_events {
 	WP_API_EVENT_SETPOLARITY,
 	WP_API_EVENT_BRI_CHAN_LOOPBACK,
 	WP_API_EVENT_RING_TRIP_DETECT,
+	WP_API_EVENT_MODEM_STATUS,
 	
 };
 
@@ -1423,6 +1435,9 @@ enum wanpipe_aft_api_events {
 		((mode) == WP_API_EVENT_DISABLE) ? "Disable" :		\
 						"(Unknown mode)"
 
+#define WP_API_EVENT_SET		0x01
+#define WP_API_EVENT_GET		0x02
+
 #define WP_API_EVENT_RXHOOK_OFF		0x01
 #define WP_API_EVENT_RXHOOK_ON		0x02
 
@@ -1459,8 +1474,12 @@ typedef struct {
 				} dtmf;
 			} u_event;
 		} wp_api_event;
+		api_serial_hdr_t serial;
 		unsigned char	reserved[12];
 	}hdr_u;
+#define wp_api_rx_hdr_error_flag			error_flag
+#define wp_api_rx_hdr_time_stamp			time_stamp
+#define wp_api_rx_hdr_event_type			event_type
 #define wp_api_rx_hdr_event_channel 		hdr_u.wp_api_event.channel
 #define wp_api_rx_hdr_event_rxhook_state 	hdr_u.wp_api_event.u_event.rxhook.state
 #define wp_api_rx_hdr_event_ring_state 		hdr_u.wp_api_event.u_event.ring.state
@@ -1468,6 +1487,7 @@ typedef struct {
 #define wp_api_rx_hdr_event_dtmf_type 		hdr_u.wp_api_event.u_event.dtmf.type
 #define wp_api_rx_hdr_event_dtmf_port 		hdr_u.wp_api_event.u_event.dtmf.port
 #define wp_api_rx_hdr_event_ringdetect_state 	hdr_u.wp_api_event.u_event.ring.state
+#define wp_api_rx_hdr_event_serial_status	hdr_u.serial.status
 } api_rx_hdr_t;
 
 typedef struct {
@@ -1487,14 +1507,15 @@ typedef struct {
 	unsigned char	data[8];
 } api_tx_hdlc_rpt_hdr_t;
 
+
+
 typedef struct {
 	u_int8_t	type;
-	u_int8_t	mode; 
+	u_int8_t	mode;
 	u_int8_t	tone;
 	u_int16_t	channel;
 	u_int16_t	polarity;
 	u_int16_t	ohttimer;
-	
 } api_tdm_event_hdr_t;
 
 typedef struct {
@@ -1513,6 +1534,7 @@ typedef struct {
 
 #define wp_api_tx_hdr_hdlc_rpt_len	hdr_u.hdlc_rpt.len
 #define wp_api_tx_hdr_hdlc_rpt_data	hdr_u.hdlc_rpt.data
+#define wp_api_tx_hdr_event_serial_status	hdr_u.event.tone
 
 } api_tx_hdr_t;
 
