@@ -220,6 +220,12 @@ typedef struct sfm			/* SDLA firmware file structire */
 #define AFT_SECURITY_CPLD_SHIFT		0x02
 #define AFT_SECURITY_CPLD_MASK		0x03
 
+#define AFT_A300_VER_CUSTOMER_ID	0x0A
+#define AFT_A300_VER_SHIFT		6
+#define AFT_A300_VER_MASK		0x03
+#define AFT_A300_CUSTOMER_ID_SHIFT	0
+#define AFT_A300_CUSTOMER_ID_MASK	0x3F
+
 /* AFT SHARK CPLD */
 #define AFT_SH_CPLD_BOARD_CTRL_REG	0x00
 #define AFT_SH_CPLD_BOARD_STATUS_REG	0x01
@@ -319,7 +325,7 @@ typedef struct sfm			/* SDLA firmware file structire */
 		(adptr_subtype == AFT_SUBTYPE_SHARK)	? "SHARK" : ""
 
 #define AFT_PCITYPE_DECODE(hwcard)				\
-		((hwcard)->pci_bridge_dev) ? " PCIe" : " PCI"
+		((hwcard)->pci_bridge_dev) ? "PCIe" : "PCI"
 
 #if defined(__WINDOWS__)
 #define DECODE_CARD_SUBTYPE(card_sub_type)						\
