@@ -9,6 +9,7 @@
 #               as published by the Free Software Foundation; either version
 #               2 of the License, or (at your option) any later version.
 # ----------------------------------------------------------------------------
+# Oct 07   2008  2.21   Jignesh Patel 	Dahdi Soft-EC conf support for Analog & A101/2 cards
 # Sep 30   2008  2.20	Jignesh Patel   Configuration Support for Dahdi
 # Aug 20   2008  2.19	Jignesh Patel 	Suppor for HP TDM API for A10x added hp_a100
 # 					Update A10x.pm-for SH and old a101/2cards
@@ -44,7 +45,7 @@ system('clear');
 print "\n########################################################################";
 print "\n#    		           Sangoma Wanpipe                              #";
 print "\n#        Dahdi/Zaptel/SMG/TDMAPI/BOOT Configuration Script             #";
-print "\n#                             v2.20                                    #";
+print "\n#                             v2.21                                    #";
 print "\n#                     Sangoma Technologies Inc.                        #";
 print "\n#                        Copyright(c) 2008.                            #";
 print "\n########################################################################\n\n";
@@ -219,6 +220,7 @@ my $dahdi_installed=$FALSE;
 my $modprobe_list=`$module_list`;
 my $is_ss7_xmpt2_only = $FALSE;
 my $zaptel_dahdi_installed=$FALSE;
+my $dahdi_echo='mg2';
 
 my $def_chunk_size=40;
 my $def_mtu_mru=' ';
@@ -1127,7 +1129,7 @@ sub copy_config_files{
 }
 
 sub unload_zap_modules{
-	my @modules_list = ("ztdummy","wctdm","wcfxo","wcte11xp","wct1xxp","wct4xxp","tor2","zttranscode","wcusb", "wctdm24xxp","xpp_usb","xpp" ,"wcte12xp","opvxa1200", "dahdi_dummy" , "dahdi", "zaptel");
+	my @modules_list = ("ztdummy","wctdm","wcfxo","wcte11xp","wct1xxp","wct4xxp","tor2","zttranscode","wcusb", "wctdm24xxp","xpp_usb","xpp" ,"wcte12xp","opvxa1200", "dahdi_dummy" ,"dahdi_echocan_mg2", "dahdi", "zaptel");
 	foreach my $module (@modules_list) {	
 		if ($modprobe_list =~ m/$module /){
 			exec_command("$module_unload $module");
@@ -2095,6 +2097,12 @@ sub config_t1e1{
 			$card->fe_cpu($5);
 			
 			my $hwec=0;
+			
+			if($dahdi_installed == $TRUE) {
+					$card->dahdi_conf('YES');
+					$card->dahdi_echo($dahdi_echo)
+				}
+
 			if ( $dev =~ /HWEC=(\d+)/){
 				if($1 gt 0){
 					$hwec=1;
@@ -2107,6 +2115,7 @@ sub config_t1e1{
 				$card->hwec_mode('NO');
 			}else{
 				$card->hwec_mode('YES');
+				
 			}
 			my $port=$6;
 			if ($6 eq 'PRI') {
@@ -2768,11 +2777,16 @@ sub config_analog{
 			$card->pci_bus($4);
 			$card->fe_cpu($5);
 			my $hwec=$7;
+			if($dahdi_installed == $TRUE) {
+					$card->dahdi_conf('YES');
+					$card->dahdi_echo($dahdi_echo)
+				}
 			if ($hwec==0){
 				$card->hwec_mode('NO');
 			}
 			else{
 				$card->hwec_mode('YES');
+				
 			}
 			if ($card->card_model eq '200' | $card->card_model eq '400'){
 				$num_analog_devices_total++;
